@@ -38,13 +38,21 @@ LockScreen::LockScreen()
 
     m_View = new QGraphicsView(&m_Scene);
     m_View->setWindowFlags(Qt::Dialog);
-    m_View->setRenderHint(QPainter::Antialiasing, LockScreen::Settings->value("Main/Antialiasing", 1).toInt() == 1);
+    m_View->setRenderHint(QPainter::Antialiasing, LockScreen::Settings->value("Main/Antialiasing", 1).toInt() == 1);    
     m_View->setCacheMode(QGraphicsView::CacheBackground);
     m_View->setViewportUpdateMode(QGraphicsView::BoundingRectViewportUpdate);
     m_View->setFrameStyle(QFrame::NoFrame);
     m_View->setContentsMargins(0,0,0,0);
     m_View->setOptimizationFlag(QGraphicsView::DontSavePainterState, true);
-    m_View->setAttribute(Qt::WA_TranslucentBackground, false);
+
+    if (LockScreen::Settings->value("Main/TransparentBackground", 0).toInt() == 1){
+        m_View->setAttribute(Qt::WA_TranslucentBackground, true);
+        QPalette p = m_View->viewport()->palette();
+        p.setColor(QPalette::Base, Qt::transparent);
+        m_View->viewport()->setPalette(p);
+    }else{
+        m_View->setAttribute(Qt::WA_TranslucentBackground, false);
+    }
 
     m_WasPortrait = LsWidget::isPortrait();
     m_isDialogActive = false;
@@ -112,6 +120,17 @@ LockScreen::LockScreen()
                  "com.nokia.system_ui.signal",
                  "alarm_dialog_status", this, SLOT(onAlarmDialogStatusChanged(QDBusMessage)));
 
+/*    conn.connect("",
+                 "/org/freedesktop/Hal/devices/platform_kb_lock",
+                 "org.freedesktop.Hal.Device",
+                 "PropertyModified", this, SLOT(onUnlockButton(QDBusMessage)));
+
+    conn.connect("",
+                 "/org/freedesktop/Hal/devices/platform_slide",
+                 "org.freedesktop.Hal.Device",
+                 "PropertyModified", this, SLOT(onUnlockButton(QDBusMessage)));
+*/
+
     m_View->setAttribute(Qt::WA_Maemo5NonComposited);
 #endif    
 
@@ -212,8 +231,16 @@ LsWidget* LockScreen::createWidget(QString type, QString name)
         return new LsText(name);
     else if (type == "Weather")
         return new LsWeather(name);
-    else if (type == "Wifi")
+    else if (type == "Wifi" || type == "Internet")
         return new LsWifi(name);
+    else if (type == "OperatorName")
+        return new LsOperatorName(name);
+    else if (type == "SignalStrength")
+        return new LsPhoneSignal(name);
+    else if (type == "RadioMode")
+        return new LsRadioMode(name);
+    else if (type == "Bluetooth")
+        return new LsBluetooth(name);
     return NULL;
 }
 
@@ -238,7 +265,7 @@ void LockScreen::setBackground()
         if (!bkg.isEmpty())
             m_Scene.setBackgroundBrush(QPixmap(bkg));
         else
-            m_Scene.setBackgroundBrush(QBrush(QColor(0,0,0)));
+            m_Scene.setBackgroundBrush(QBrush(QColor(0,0,0,0)));
 
         m_BkgPath = bkg;
     }
@@ -317,6 +344,12 @@ void LockScreen::onCallStateChanged(QString state)
 }
 
 #ifdef Q_WS_MAEMO_5
+/*void LockScreen::onUnlockButton(QDBusMessage)
+{
+    if (m_tklockState == MCE_TK_LOCKED)
+        hide();
+}*/
+
 void LockScreen::onAlarmDialogStatusChanged(QDBusMessage msg)
 {
     int status = 0;
