@@ -29,7 +29,7 @@ public:
     void applySettings();
 
 private:
-    Qt::AlignmentFlag m_Alignment;
+    int m_Alignment;
     QFont m_Font;
     QColor m_Color;
     QString m_Text;
