@@ -36,5 +36,9 @@
 #include "lstext.h"
 #include "lsweather.h"
 #include "lswifi.h"
+#include "lsoperatorname.h"
+#include "lsphonesignal.h"
+#include "lsradiomode.h"
+#include "lsbluetooth.h"
 
 #endif // LSWIDGETS_H
