@@ -31,6 +31,8 @@ public:
 
 private:
     bool m_Connected;
+    QString m_Wifi;
+    QString m_Gprs;
     QPixmap m_Image;
 
 private slots:
